/******************************************************************************
 * FILE:
 *    uc_lld.h
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC57
 *
 * DESCRIPTION:
 *    Low Level Driver API interface for SPC58 uC family
 *
 * FILE HISTORY:
 *    V1.0    23.09.2017     RO
 *       > Initial version
 *    V2.0    25.01.2018     RO
 *       > File name rename and file header update
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

#ifndef UC_LLD_H
#define UC_LLD_H

/* include BSP header file to get derivative dependent base addresses */
#include "bsp.h"


/* ============================================================================
 *                 LLD API
 * ==========================================================================*/

/* CGM (Clock) */
void uc_cgm_EnableXOSC(void);
void uc_cgm_EnablePLL(uint32_t instance, uint32_t prediv, uint32_t mfd, uint32_t rfdphi, uint32_t rfdhpi1);
void uc_cgm_SwitchSystemClock(uint32_t sysclk);
void uc_cgm_SetScClockDiv(uint32_t dc, uint32_t div);
void uc_cgm_SelectAuxClock(uint32_t aux, uint32_t inclk);
void uc_cgm_SetAuxClockDiv(uint32_t aux, uint32_t dc, uint32_t div);

/* MC_ME */
void uc_me_EnableAllPeripheralsInDRUN(void);
void uc_me_ChangeMode2DRUN(void);

/* CORE */
void uc_core_PrepareStart(uint32_t core_nb, uint32_t* reset_vector);
void uc_core_EnableICache(void);
void uc_core_EnableDCache(void);
uint32_t uc_core_GetCurrentCore(void);

/* SIUL */
void uc_siul_EnableInput(uint32_t pad_nb, uint32_t pullup_enable, uint32_t pulldown_enable);
void uc_siul_EnableOutput(uint32_t pad_nb, uint32_t oerc, uint32_t type, uint32_t source);
void uc_siul_SetGPIO(uint32_t pad_nb, uint8_t value);
uint8_t uc_siul_GetGPIO(uint32_t pad_nb);

/* SWT */
void uc_swt_Disable(uint32_t base);

/* PFLASH */
void uc_pflash_SetPFCR1(uint32_t base, uint32_t apc, uint32_t ws, uint32_t pflim);
void uc_pflash_SetPFCR2(uint32_t base, uint32_t pflim);
void uc_pflash_SetPFCR3(uint32_t base, uint32_t p0wcfg, uint32_t p1wcfg, uint32_t arb);

/* PRAM */
void uc_pram_SetPRCR1(uint32_t base, uint32_t pri, uint32_t p0rb, uint32_t p1rb, uint32_t ftdis);

/* PIT */
void uc_pit_Enable(void);
void uc_pit_ReloadChannel(uint32_t channel, uint32_t reload_value);
void uc_pit_EnableChannelIsr(uint32_t channel);
void uc_pit_StartChannel(uint32_t channel);
void uc_pit_StopChannel(uint32_t channel);
void uc_pit_ClearChannelIsrFlag(uint32_t channel);
uint32_t uc_pit_IsChannelIsrFlag(uint32_t channel);
uint32_t uc_pit_GetChannelCurrentValue(uint32_t channel);

/* INTC */
void uc_intc_SetVTBA(uint32_t coreId, uint32_t* table);
void uc_intc_SetCurrentPriority(uint32_t coreId, uint32_t priority);
void uc_intc_SetPSR(uint32_t psr_nb, uint32_t coreId, uint32_t priority);
void uc_intc_SetBCR(uint32_t coreId, uint32_t mode);
void uc_intc_EndOfInterrupt(uint32_t coreId);

#endif /* UC_LLD_H */
