/******************************************************************************
 * FILE: uc_spc58nn84_start_core.c
 *
 * UC ARCHITECTURE:
 *    PowerPC
 *
 * UC FAMILY:
 *    SPC57
 *
 * DESCRIPTION:
 *    uC derivative start core implementation. Each derivative might have
 *    special startup sequence and register access.
 *
 * FILE HISTORY:
 *    V1.0    09.02.2018     RO
 *       > Initial version
 *
 ******************************************************************************
 * Copyright (C) 2015-2018 HighTec EDV-Systeme GmbH.  All rights reserved.
 * This is proprietary software. Any use of the software requires a written
 * license agreement with HighTec EDV-Systeme GmbH. Please contact for
 * detailed license information: info@hightec-rt.com.
 *****************************************************************************/

/* Include BSP header file to get API declaration and types */
#include "bsp.h"

/* ----------------------------------------------------------------------------
 * FUNCTION: uc_StartCore()
 *    Starts requested Core with default setting of the reset_vector
 *    to _crt0_reset() entry point. If user wants a different reset vector,
 *    he needs to call LLD function directly.
 * INPUT:
 *    core_nb : core to start
 * --------------------------------------------------------------------------*/
extern void _crt0_reset(void);
void uc_StartCore(uint32_t core_nb)
{
	/* do not switch current core */
	if (core_nb == uc_core_GetCurrentCore())
		return;

	/* start requested core */
	switch (core_nb)
	{
	case 0:
		uc_core_PrepareStart(UC_CORE0_START_ID, (uint32_t*) _crt0_reset);
		break;
	default:
		break;
	}

	/* Execute change mode to enable inactive cores*/
	uc_me_ChangeMode2DRUN();
}
